import { parseData } from '@stenodb/utils';
import { plainToClass } from 'class-transformer';
export class BrowserStorage {
    constructor(name, storage, entity, initialData) {
        Object.defineProperty(this, "name", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "storage", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "entity", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "data", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: null
        });
        Object.defineProperty(this, "initialData", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: null
        });
        this.name = name;
        this.storage = storage;
        this.entity = entity;
        if (initialData) {
            this.initialData = initialData;
        }
    }
    plainData(data = this.data) {
        if (!data)
            return null;
        const parsedData = typeof data === 'string' ? parseData(data).toJSON() : data;
        return plainToClass(this.entity, parsedData);
    }
    read() {
        const data = this.storage.getItem(this.name);
        this.data = data ? this.plainData(data) : null;
    }
    write() {
        this.storage.setItem(this.name, parseData(this.data).toString());
    }
    reset() {
        if (!this.initialData)
            return;
        this.data = plainToClass(this.entity, this.initialData);
        this.write();
    }
    exists() {
        return this.read() !== null;
    }
}
//# sourceMappingURL=WebStorage.js.map